#
# Configuration file for using the XML library in GNOME applications
#

prefix=/usr/local
exec_prefix=${prefix}
includedir=${prefix}/include
libdir=${exec_prefix}/lib

XML2_LIBDIR="-L${libdir}"
XML2_LIBS="-lxml2 -lz -L/usr/local/lib -lgiconv -lm -L/usr/local/lib"
XML2_INCLUDEDIR="-I${includedir}/libxml2/libxml -I${includedir}/libxml2 -I/usr/local/include"
MODULE_VERSION="xml2-2.4.12"

